import type {SearchOptions} from '../support/helpers';
import {findGroupRow, submitGroupSearch} from '../support/helpers';

const school = Cypress.env('SCHOOL');
const schoolClasses = Cypress.env('SCHOOL_CLASSES');

describe('school class handling tests', () => {
  it('deletes a school class correctly', () => {
    cy.login();
    cy.visit('/');
    const searchOptions: SearchOptions = {
      schoolSelection: school,
      quickSearch: schoolClasses[0].name,
    };
    submitGroupSearch(searchOptions);
    const tr = findGroupRow(schoolClasses[0], {assertExists: true});
    tr.find('td:first-child input').click({scrollBehavior: 'center'});
    cy.get('.uGrid__header .uButton')
      .eq(2)
      .should('not.have.attr', 'disabled');
    cy.get('.uGrid__header .uButton')
      .eq(2)
      .click();
    cy.get('.uConfirmDialog .uButton--primary')
      .click();
    cy.get('.uGrid__tableWrapper tbody tr')
      .should('have.length', 0);
    submitGroupSearch(searchOptions);
    cy.get('.uGrid__tableWrapper tbody tr')
      .should('have.length', 0);
  });

  it('deletes multiple school classes correctly', () => {
    cy.login();
    cy.visit('/');
    const searchOptions: SearchOptions = {schoolSelection: school};
    submitGroupSearch(searchOptions);
    findGroupRow(schoolClasses[1], {assertExists: true}).then($row => {
      cy.wrap($row).find('td:first-child input').click();
    });
    findGroupRow(schoolClasses[2], {assertExists: true}).then($row => {
      cy.wrap($row).find('td:first-child input').click();
    });
    cy.get('.uGrid__header .uButton')
      .eq(2)
      .should('not.have.attr', 'disabled');
    cy.get('.uGrid__header .uButton')
      .eq(2)
      .click();
    cy.get('.uConfirmDialog .uButton--primary')
      .click();
  });


  it('edits school class correctly', () => {
    cy.login();
    const searchOptions: SearchOptions = {schoolSelection: school};
    submitGroupSearch(searchOptions);
    findGroupRow(schoolClasses[3], {assertExists: true}).then($row => {
      cy.wrap($row).find('td:first-child input').click();
    });
    cy.get('.uGrid__header .uButton')
      .eq(1)
      .within($button => {
        cy.wrap($button).should('not.have.attr', 'disabled');
        cy.wrap($button).click();
      });
    cy.url().should('contain', `${Cypress.config().baseUrl}/schoolClass/edit/`);
    cy.get('input[name="name"]')
      .clear({scrollBehavior: 'center'})
      .type('Changed name', {scrollBehavior: 'center'});
    cy.get('.listView__header__buttons [type="button"]')
      .eq(0)
      .click();
    cy.get('.uStandbyWrapper').should('have.length', 1);
    cy.get('.uStandbyWrapper').should('have.length', 0);
    submitGroupSearch(searchOptions);
  });
});
